Module: Isaca::Request::ReportConsent
- Defined in:
- lib/isaca/requests/report_consent.rb
Class Method Summary collapse
-
.get(imis_id, options = {}) ⇒ Faraday::Response
Method used to report marketing consent and acceptance of the privacy policy.
-
.send_request(imis_id, options = {}) ⇒ Faraday::Response
Method used to send request – exists to ease testing.
Class Method Details
.get(imis_id, options = {}) ⇒ Faraday::Response
Method used to report marketing consent and acceptance of the privacy policy. ISACA assumes that when you send this request that the user has accepted the privacy statement. Plan your user interface with this in mind and only submit this request when you have validated the acceptance of the privacy policy.
Options
- marketing
-
Consent for marketing. Acceptable values are 0 [for NO] and 1 [for YES].
15 16 17 |
# File 'lib/isaca/requests/report_consent.rb', line 15 def self.get(imis_id, ={}) self.send_request(imis_id, {marketing: 0}.merge()) end |
.send_request(imis_id, options = {}) ⇒ Faraday::Response
Method used to send request – exists to ease testing
Options
- marketing
-
Consent for marketing. Acceptable values are 0 [for NO] and 1 [for YES].
30 31 32 33 34 35 36 |
# File 'lib/isaca/requests/report_consent.rb', line 30 def self.send_request(imis_id, ={}) Isaca::Request.get do |request| request.path = request.path + '/ReportConsent' request.params['MarketingConsent'] = [:marketing] request.params['iMISID'] = imis_id end end |